// increment.cc - Increment
#define VERSION "v1.0"
// GPLed - Stephan T. Lavavej - http://stl.caltech.edu

#include <cstdlib>
#include <iostream>
#include <iomanip>
#include <string>
#include <sstream>
using namespace std;

string synthFileName(int width, int i, string ext) {
    ostringstream os;
    os << setfill('0') << setw(width) << i;
    return os.str() + "." + ext;
}

int main(int argc, char *argv[]) {
    cout << "Increment " VERSION " [GPLed] by Stephan T. Lavavej, http://stl.caltech.edu" << endl;

    if (argc != 6) {
        cout << "GPL:   http://www.gnu.org/licenses/gpl.txt" << endl;
        cout << "USAGE: increment increment# width# start# end# extension" << endl;
        cout << "EX:    increment 5          4      0000   0137 png" << endl;
        cout << "EX:    increment -1         3      010    047  txt" << endl;
        cout << "NOTE:  Range is inclusive. Increment can be negative." << endl;
        exit(EXIT_SUCCESS);
    }

    const int    inc   = atoi(argv[1]);
    const int    width = atoi(argv[2]);
    const int    start = atoi(argv[3]);
    const int    end   = atoi(argv[4]);
    const string ext   = argv[5];

    if (inc > 0) {        // Iterate backwards
        for (int i = end; i >= start; i--) {
            rename(synthFileName(width, i, ext).c_str(), synthFileName(width, i + inc, ext).c_str());
        }
    } else if (inc < 0) { // Iterate forwards
        for (int i = start; i <= end; i++) {
            rename(synthFileName(width, i, ext).c_str(), synthFileName(width, i + inc, ext).c_str());
        }
    }
}

// Version History:
// v1.0 - Initial C++ version
